==> aria2-1.11.2.tar.gz: aria2-1.11.2/src/DHTPingReplyMessage.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "DHTPingReplyMessage.h"

#include <cstring>

#include "DHTNode.h"
#include "DHTMessageCallback.h"

namespace aria2 {

const std::string DHTPingReplyMessage::PING("ping");

DHTPingReplyMessage::DHTPingReplyMessage
(const SharedHandle<DHTNode>& localNode,
 const SharedHandle<DHTNode>& remoteNode,
 const unsigned char* id,
 const std::string& transactionID):
  DHTResponseMessage(localNode, remoteNode, transactionID)
{
  memcpy(id_, id, DHT_ID_LENGTH);
}

DHTPingReplyMessage::~DHTPingReplyMessage() {}

void DHTPingReplyMessage::doReceivedAction() {}

SharedHandle<Dict> DHTPingReplyMessage::getResponse()
{
  SharedHandle<Dict> rDict = Dict::g();
  rDict->put(DHTMessage::ID, String::g(id_, DHT_ID_LENGTH));
  return rDict;
}

const std::string& DHTPingReplyMessage::getMessageType() const
{
  return PING;
}

void DHTPingReplyMessage::accept(DHTMessageCallback* callback)
{
  callback->visit(this);
}

} // namespace aria2

==> aria2_1.36.0.orig.tar.gz: aria2-1.36.0/src/DHTPingReplyMessage.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "DHTPingReplyMessage.h"

#include <cstring>

#include "DHTNode.h"
#include "DHTMessageCallback.h"

namespace aria2 {

const std::string DHTPingReplyMessage::PING("ping");

DHTPingReplyMessage::DHTPingReplyMessage(
    const std::shared_ptr<DHTNode>& localNode,
    const std::shared_ptr<DHTNode>& remoteNode, const unsigned char* id,
    const std::string& transactionID)
    : DHTResponseMessage(localNode, remoteNode, transactionID)
{
  memcpy(id_, id, DHT_ID_LENGTH);
}

void DHTPingReplyMessage::doReceivedAction() {}

std::unique_ptr<Dict> DHTPingReplyMessage::getResponse()
{
  auto rDict = Dict::g();
  rDict->put(DHTMessage::ID, String::g(id_, DHT_ID_LENGTH));
  return rDict;
}

const std::string& DHTPingReplyMessage::getMessageType() const { return PING; }

void DHTPingReplyMessage::accept(DHTMessageCallback* callback)
{
  callback->visit(this);
}

} // namespace aria2
